@@ -39,8 +39,4 @@ class S3DS(DataSource):
         return file_ds.df, file_ds._col_map
 
     def name(self):
-        return '{}: {}/{}'.format(
-            self.__class__.__name__,
-            self.bucket_name,
-            self.file_path
-        )
+        return 'S3 - {}/{}'.format(self.bucket_name, os.path.basename(self.file_path))
