@@ -304,8 +304,12 @@ class TypeDeductor(BaseModule):
         else:
             sample_df = input_data.data_frame
 
-        if get_nr_procs() > 1 and False:
-            pool = mp.Pool(processes=get_nr_procs())
+        nr_procs = get_nr_procs(self.transaction.lmd.get('max_processes', None),
+                                self.transaction.lmd.get('max_per_proc_usage', None),
+                                sample_df)
+        if nr_procs > 1 and False:
+            self.transaction.log.info(f'Using {nr_procs} processes to deduct types.')
+            pool = mp.Pool(processes=nr_procs)
             # Make type `object` so that dataframe cells can be python lists
             answer_arr = pool.map(partial(get_column_data_type, lmd=self.transaction.lmd), [
                 (sample_df[x].dropna(), input_data.data_frame[x], x) for x in sample_df.columns.values
@@ -335,8 +339,8 @@ class TypeDeductor(BaseModule):
             stats_v2[col_name]['typing'] = type_data
             stats_v2[col_name]['additional_info'] = additional_info
 
-        if get_nr_procs() > 1:
-            pool = mp.Pool(processes=get_nr_procs())
+        if nr_procs > 1:
+            pool = mp.Pool(processes=nr_procs)
             answer_arr = pool.map(get_identifier_description_mp, [
                 (input_data.data_frame[x],
                     x,
@@ -352,9 +356,6 @@ class TypeDeductor(BaseModule):
                 answer = get_identifier_description_mp([input_data.data_frame[x], x, stats_v2[x]['typing']['data_type'], stats_v2[x]['typing']['data_subtype'], stats_v2[x]['additional_info']])
                 answer_arr.append(answer)
 
-
-
-
         for i, col_name in enumerate(sample_df.columns.values):
             # work with the full data
             stats_v2[col_name]['identifier'] = answer_arr[i]
